coastpy.utils package
=====================

Submodules
----------

coastpy.utils.config module
---------------------------

.. automodule:: coastpy.utils.config
   :members:
   :undoc-members:
   :show-inheritance:

coastpy.utils.dask\_utils module
--------------------------------

.. automodule:: coastpy.utils.dask_utils
   :members:
   :undoc-members:
   :show-inheritance:

coastpy.utils.size\_utils module
--------------------------------

.. automodule:: coastpy.utils.size_utils
   :members:
   :undoc-members:
   :show-inheritance:

coastpy.utils.xr\_utils module
------------------------------

.. automodule:: coastpy.utils.xr_utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: coastpy.utils
   :members:
   :undoc-members:
   :show-inheritance:
